==> l7-layers-2.10.2.tgz: package/es/tile/tileFactory/VectorTile.js <==
import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _inherits from "@babel/runtime/helpers/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _regeneratorRuntime from "@babel/runtime/regenerator";

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

import Tile from "./Tile";
import { getTileLayer, getMaskLayer } from "./util";

var VectorTile = /*#__PURE__*/function (_Tile) {
  _inherits(VectorTile, _Tile);

  var _super = _createSuper(VectorTile);

  function VectorTile() {
    _classCallCheck(this, VectorTile);

    return _super.apply(this, arguments);
  }

  _createClass(VectorTile, [{
    key: "initTileLayer",
    value: function () {
      var _initTileLayer = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var attributes, layerOptions, vectorLayer, maskLayer, sourceOptions, layer, mask;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                attributes = this.parent.getLayerAttributeConfig();
                layerOptions = this.parent.getLayerConfig();
                vectorLayer = getTileLayer(this.parent.type);
                maskLayer = getMaskLayer(this.parent.type);
                layerOptions.mask = !!maskLayer;
                sourceOptions = this.getSourceOption();

                if (sourceOptions) {
                  _context.next = 9;
                  break;
                }

                this.isLoaded = true;
                return _context.abrupt("return");

              case 9:
                layer = new vectorLayer(_objectSpread({}, layerOptions)).source(sourceOptions.data, sourceOptions.options); // 初始化数据映射

                Object.keys(attributes).forEach(function (type) {
                  var _attributes$attr, _attributes$attr2;

                  var attr = type; // @ts-ignore

                  layer[attr]((_attributes$attr = attributes[attr]) === null || _attributes$attr === void 0 ? void 0 : _attributes$attr.field, (_attributes$attr2 = attributes[attr]) === null || _attributes$attr2 === void 0 ? void 0 : _attributes$attr2.values);
                });

                if (!maskLayer) {
                  _context.next = 15;
                  break;
                }

                mask = new maskLayer({
                  layerType: "MaskLayer"
                }).source({
                  type: 'FeatureCollection',
                  features: [this.sourceTile.bboxPolygon]
                }, {
                  parser: {
                    type: 'geojson'
                  }
                }); // .style({
                //   opacity: 1
                // });

                _context.next = 15;
                return this.addMask(layer, mask);

              case 15:
                _context.next = 17;
                return this.addLayer(layer);

              case 17:
                this.setLayerMinMaxZoom(layer);
                this.isLoaded = true;

              case 19:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function initTileLayer() {
        return _initTileLayer.apply(this, arguments);
      }

      return initTileLayer;
    }() // Todo 校验数据有效性

  }, {
    key: "beforeInit",
    value: function beforeInit() {}
  }, {
    key: "getSourceOption",
    value: function getSourceOption() {
      var rawSource = this.parent.getSource();

      var _this$parent$getLayer = this.parent.getLayerConfig(),
          _this$parent$getLayer2 = _this$parent$getLayer.sourceLayer,
          sourceLayer = _this$parent$getLayer2 === void 0 ? 'defaultLayer' : _this$parent$getLayer2,
          _this$parent$getLayer3 = _this$parent$getLayer.featureId,
          featureId = _this$parent$getLayer3 === void 0 ? 'id' : _this$parent$getLayer3;

      var vectorLayer = this.sourceTile.data.layers[sourceLayer];

      if (!vectorLayer) {
        return false;
      }

      var features = vectorLayer.features;
      return {
        data: {
          type: 'FeatureCollection',
          features: features
        },
        options: {
          parser: {
            type: 'geojson',
            featureId: featureId
          },
          transforms: rawSource.transforms
        }
      };
    }
  }, {
    key: "setLayerMinMaxZoom",
    value: function setLayerMinMaxZoom(layer) {
      // 文本图层设置，可见范围
      if (layer.getModelType() === 'text') {
        layer.updateLayerConfig({
          maxZoom: this.z + 1,
          minZoom: this.z - 1
        });
      }
    }
  }]);

  return VectorTile;
}(Tile);

export { VectorTile as default };

==> l7-layers-2.10.3.tgz: package/es/tile/tileFactory/VectorTile.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _regeneratorRuntime from "@babel/runtime/regenerator";

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

import Tile from "./Tile";
import { getTileLayer, getMaskLayer } from "./util";

var VectorTile = /*#__PURE__*/function (_Tile) {
  _inherits(VectorTile, _Tile);

  var _super = _createSuper(VectorTile);

  function VectorTile() {
    _classCallCheck(this, VectorTile);

    return _super.apply(this, arguments);
  }

  _createClass(VectorTile, [{
    key: "initTileLayer",
    value: function () {
      var _initTileLayer = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var attributes, layerOptions, vectorLayer, maskLayer, sourceOptions, layer, mask;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                attributes = this.parent.getLayerAttributeConfig();
                layerOptions = this.parent.getLayerConfig();
                vectorLayer = getTileLayer(this.parent.type);
                maskLayer = getMaskLayer(this.parent.type);
                layerOptions.mask = !!maskLayer;
                sourceOptions = this.getSourceOption();

                if (sourceOptions) {
                  _context.next = 9;
                  break;
                }

                this.isLoaded = true;
                return _context.abrupt("return");

              case 9:
                layer = new vectorLayer(_objectSpread({}, layerOptions)).source(sourceOptions.data, sourceOptions.options); // 初始化数据映射

                Object.keys(attributes).forEach(function (type) {
                  var _attributes$attr, _attributes$attr2;

                  var attr = type; // @ts-ignore

                  layer[attr]((_attributes$attr = attributes[attr]) === null || _attributes$attr === void 0 ? void 0 : _attributes$attr.field, (_attributes$attr2 = attributes[attr]) === null || _attributes$attr2 === void 0 ? void 0 : _attributes$attr2.values);
                });

                if (!maskLayer) {
                  _context.next = 15;
                  break;
                }

                mask = new maskLayer({
                  layerType: "MaskLayer"
                }).source({
                  type: 'FeatureCollection',
                  features: [this.sourceTile.bboxPolygon]
                }, {
                  parser: {
                    type: 'geojson'
                  }
                }); // .style({
                //   opacity: 1
                // });

                _context.next = 15;
                return this.addMask(layer, mask);

              case 15:
                _context.next = 17;
                return this.addLayer(layer);

              case 17:
                this.setLayerMinMaxZoom(layer);
                this.isLoaded = true;

              case 19:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function initTileLayer() {
        return _initTileLayer.apply(this, arguments);
      }

      return initTileLayer;
    }() // Todo 校验数据有效性

  }, {
    key: "beforeInit",
    value: function beforeInit() {}
  }, {
    key: "getSourceOption",
    value: function getSourceOption() {
      var rawSource = this.parent.getSource();

      var _this$parent$getLayer = this.parent.getLayerConfig(),
          _this$parent$getLayer2 = _this$parent$getLayer.sourceLayer,
          sourceLayer = _this$parent$getLayer2 === void 0 ? 'defaultLayer' : _this$parent$getLayer2,
          _this$parent$getLayer3 = _this$parent$getLayer.featureId,
          featureId = _this$parent$getLayer3 === void 0 ? 'id' : _this$parent$getLayer3;

      var features = this.getFeatures(sourceLayer);
      return {
        data: {
          type: 'FeatureCollection',
          features: features
        },
        options: {
          parser: {
            type: 'geojson',
            featureId: featureId
          },
          transforms: rawSource.transforms
        }
      };
    }
  }, {
    key: "setLayerMinMaxZoom",
    value: function setLayerMinMaxZoom(layer) {
      // 文本图层设置，可见范围
      if (layer.getModelType() === 'text') {
        layer.updateLayerConfig({
          maxZoom: this.z + 1,
          minZoom: this.z - 1
        });
      }
    }
  }]);

  return VectorTile;
}(Tile);

export { VectorTile as default };
